
/* Master file for figures included in Burgess, Greenstone, Ryan, and Sudarshan 2019 JEP submission
		titled "The Consequences of Treating Electricity as a Right"

	Instructions to run:
	
	-- For .do files, set the file path below to the directory containing Code and Data folders
*/		global ROOT "/Users/vishannigam/Downloads/Replication Files"
/*
	-- For .R files, open and set the ROOT variable as the same file path
	
	-- For .xlsx Excel files, open the file
	
	For Stata and R files, running the code will generate output figures/data in the ROOT directory.
	
		
		
	Notes:
	-- Figure 2, Figure 6, and Table 2 use administrative/survey data from ongoing research in rural Bihar 
		(the Bihar Electrification project) in partnership with Bihar state-run distribution companies (utilities).
		The administrative billing data are not available to the public, but we still provide the figure-generating code here.
		Please contact authors for more information regarding these data.
	-- Table 1 (Panel A) and Figure 3 use country-level data from the World Bank, easily accessible at https://data.worldbank.org/.

		

		
****** Figure 1
*/
*open bihar_loss_example.xlsx
/*
Data: Statistics from the Bihar 2017-18 tariff schedule, indicated in spreadsheet

Outputs: A plot of the breakdown of Bihar losses, as shown in the in the Figure tab.
		 
		
****** Figure 2
*/
// do hrs_supply_rev_rate.do
/*

Data: Feeder-month level data from North Bihar and South Bihar (separate input files) on amount billed and collected, 
	  the revenue rate (avg_rate), and daily avg. hours of electricity (avg_supply).
	  
	  (not available to the public, please contact authors with questions)
		
Outputs: -- Plot of hours of supply against revenue rate
		 -- Several summary stats that are found in the paper (incl. mean hrs of supply, distinct feeders in plot, etc)

		
****** Figure 3 
*/
do "$ROOT/Code/td_local_linear.do"
/*
Data: Cleaned World Bank country-year panel data (wb_panel.dta), originally from https://data.worldbank.org/

Outputs: Fitted values and CIs from nonparametric regression of T&D losses on pct. access to electricity
			weighted by country population and with histogram of pct. access to electricity overlaid.

			
****** Figure 5, also Table 1 (Panel B)
*/
// first run tariff_plots_clean.R in R (with the correct ROOT variable)
// 	then run tariff_plots_create.R in R (with the correct ROOT variable)
/*

Data:	Manually collected tariff schedules for 16 countries.
		Raw data in tariff_schedules_combined.xlsx
		
Outputs: Plot of mean marginal price by income quartile, weighted by discom within-country and unweighted across countries.
		Saved as mc_avg_by_income_w.pdf
		
		Statistics by income quartile for Table 2 Panel B, saved as tariffs_by_income_raw.csv	
	

****** Figure 6
*/
// do payment_by_kwh_bihar.do
/*

Data: Raw consumer-level billing data from North Bihar from 10/2017-06/2018.

	  (not available to the public, please contact authors with questions)
	  
Outputs: Plot of collection rate for billed consumers by (log) kWh consumed.


****** Figure 7
*/
do "$ROOT/Code/ihds_power_supply.do"
/*

Data: Survey responses regarding daily access to electricity from the 
		2011-2012 India Human Development Survey (IHDS)
	  
Outputs: Plot of CDF of daily hours of supply, separately for urban/rural households

*/

