/* 
 * Purpose: Plot Figure 2 (hours of supply vs revenue rate) using Bihar data
 * Note: Data are a feeder-month panel 
 */


pause on
set more off
set varabbrev off
set matsize 10000
graph drop _all
cap log close
set seed 082196
clear

*** graph fonts
set scheme s2mono
graph set window fontface "Times New Roman"

*** file paths

if "`c(os)'" == "MacOSX" {
*	global ROOT ""
	cd "$ROOT/Code"
	local DATA "$ROOT/Data"
	local OUTPUT "$ROOT/Output"
}


* month codes
local first_month_strict = 688 // may 2017
local last_month_strict = 699 // april 2018


** append north and south bihar datasets
use "`DATA'/SUPPLY_ASSIGNMENT_CONSUMPTION_REVENUE_merged.dta", clear
gen north = 1
append using "`DATA'/SB_SUPPLY_ASSIGNMENT_CONSUMPTION_REVENUE_merged.dta"
replace north = 0 if missing(north)

drop if missing(treatment) 

* generate new feeder unique ID
replace feeder_id = (north * 10000) + feeder_id

keep if treatment == 0 // control feeders only

* further subset to custom months
keep if month >= `first_month_strict' & month <= `last_month_strict'

* keep feeders with nonmissing revenue and supply data
drop if missing(avg_supply) | missing(avg_rate)


**** Graph  with histogram of rev. rate
graph twoway hist avg_rate, frac start(0) width(.1) yaxis(2) color(green%20) ytitle(" " "Fraction of Consumers                                  ", axis(2)) ylabel(0(4)24) yscale(range(0 24)) ||  ///
	scatter avg_supply avg_rate, msize(tiny) mcolor(blue) mstyle(1) yaxis(1) yscale(alt) yscale(alt axis(2)) yscale(range(0 0.5)) ///
		ylabel(0(0.05)0.25, axis(2) nogrid labsize(small)) ytick(0(0.05)0.25, add custom axis(2)) ymtick(0(0.025)0.2, add custom axis(2)) ylabel(0.5 "", add custom axis(2) notick nolabel) || ///
	lfit avg_supply avg_rate, graphregion(color(white)) lcolor(red) lstyle(solid) ///
	, xtitle("Revenue Rate") ytitle("Hours of electricity supplied" " ") ///
	title("") xlabel(0(.1)1) xscale(range(0 1)) ///
	legend(region(lcolor(white)) label(1 "Distribution of Revenue Rate (right vertical axis)") label(2 "Average Daily Hours of Electricity (left vertical axis)") label(3 "Linear Fit") order(2 3 1) cols(1)) ///
	graphregion(color(white)) plotregion(color(white)) bgcolor(white)

graph export "/../Output/fig2.pdf", replace


******* Summary statistics	
	
* Summary statistics for revenue rate
summ avg_rate, d

**** This number is reported in paper: ~17 hours/feeder
summ avg_supply, d
**** 

**** This number is reported in paper
* 172 distinct feeders used
distinct feeder_id
**** 

**** Other feeder statistics
preserve
	bysort feeder_id: gen n_months = _N
	bysort feeder_id: keep if _n == 1
	
	* Number of months available, by feeder
	tab n_months
	summ n_months
	
restore











