/******************************************
Purpose: Plot distribution of hours of supply from the 2011-12 India Human Development Survey (Figure 7)
*******************************************/

cap log close
clear
set more off
set memory 500M
pause on
version 12.0

* Switches
local clean = 1 
local both_cdf = 1

* OPENING COMMANDS:	
graph set window fontface "Times New Roman"

* global ROOT ""
cd "$ROOT/Code"
local DATA "$ROOT/Data"
local OUTPUT "$ROOT"
			
	
if `clean' == 1 {

	use "`DATA'/IHDS-Data", clear
	
	*BOTH URBAN AND RURAL HOUSEHOLDS

	tab FU1, m
	tab FU1A, m
	replace FU1A = 0 if missing(FU1A) //To include households with no grid connection in the zero hour bin
	
	* Create a new variable for the histogram bins for an empirical CDF:
	count
	local num_all_hh = `r(N)'
	count if URBAN2011 == 0
	local num_rural_hh = `r(N)'
	count if URBAN2011 == 1
	local num_urban_hh = `r(N)'
	mat hrs_cdf = (., ., ., .) // first rural households, then all households
	local runsum_all = 0
	local runsum_rur = 0
	local runsum_urb = 0
	forval hr = 0/24 {
		count if FU1A > `hr' - 1 & FU1A <= `hr' 
		local bin`hr'_allhh_frac = `r(N)' / `num_all_hh'
		count if FU1A > `hr' - 1 & FU1A <= `hr' & URBAN2011 == 0
		local bin`hr'_rurhh_frac = `r(N)' / `num_rural_hh'
		count if FU1A > `hr' - 1 & FU1A <= `hr' & URBAN2011 == 1
		local bin`hr'_urbhh_frac = `r(N)' / `num_urban_hh'
		
		local runsum_all = `runsum_all' + `bin`hr'_allhh_frac'
		local runsum_rur = `runsum_rur' + `bin`hr'_rurhh_frac'
		local runsum_urb = `runsum_urb' + `bin`hr'_urbhh_frac'
		
		mat hrs_cdf = (hrs_cdf \ `hr', `runsum_rur', `runsum_all', `runsum_urb')
	}
}

* CDF, rural urban all
if `both_cdf' == 1 {
	* Experimental bar chart
	clear
	svmat hrs_cdf
	rename hrs_cdf1 hr
	rename hrs_cdf2 rurhh_hrs
	rename hrs_cdf3 allhh_hrs
	rename hrs_cdf4 urbhh_hrs
	replace rurhh_hrs = rurhh_hrs * 100
	replace allhh_hrs = allhh_hrs * 100
	replace urbhh_hrs = urbhh_hrs * 100
	drop if hr == .
	#d ;
	twoway 
			 (
					line allhh_hrs hr, color(blue%80)
					xlabel(#20, angle(90) nogrid labsize(medsmall)) ylabel(#5, labsize(medsmall)) 
					yscale(r(0 100)) xmtick(#12, grid tstyle(none))
			 )
			 (
					line rurhh_hrs hr, color(red%80) lpattern(solid)
			 )	
			 (
					line urbhh_hrs hr, color(green%80) lpattern(solid)
			 )			 
			 , 
			legend(on order(1 "All" 2 "Rural" 3 "Urban") position(6) cols(3) region(lcolor(white))) xtitle("Daily Hours of Supply") 
			ytitle("Percent Households With N Hours or Fewer (%)", height(5)) 
			scheme(s2mono) plotregion(color(white)) graphregion(color(white)) bgcolor(white) aspectratio(0.7)  ;
	#d cr
	graph export "`OUTPUT'/CDF_three_India.png", replace
}

